@@ -9,6 +9,7 @@
 #include "link.h"
 #include "monitor.h"
 #include "plainstack.h"
+#include "signal.h"
 
 extern MonitorManager* g_monitors;
 
@@ -83,6 +84,13 @@ public:
 
     int cur_monitor;
 
+    /**
+     * @brief this signal is emitted whenever the mouse cursor have
+     * entered another window although the user has not moved the cursor
+     * manually. In this case the respective events have to be ignored.
+     */
+    Signal dropEnterNotifyEvents;
+
 private:
     std::function<int(Input, Output)> byFirstArg(MonitorCommand cmd);
 
